@@ -18,7 +18,6 @@ class User(BaseModel):
     bio: Optional[str]
     country: str
     username: str
-    skin: Skin
     create_at: datetime
     telegram_id: int
     is_activated: bool
@@ -31,7 +30,6 @@ class User(BaseModel):
     game_profiles: List[GameProfile]
     bank_cards: List[BankCard]
     city_orders: List[CityOrder]
-    skins: List[Skin]
 
     def get_gp(self, xbox: str) -> GameProfile:
         for game_profile in self.game_profiles:
